@@ -51,7 +51,8 @@ if(is.null(kk)){
       snps <- snps[rowSums(is.na(snps))==0,]
     }
     n <- ncol(snps)
-    K<-(t(snps)%*%snps+t(1-snps)%*%(1-snps))/nrow(snps)
+    #K<-(t(snps)%*%snps+t(1-snps)%*%(1-snps))/nrow(snps)
+    K<-(mrMLM::multiplication_speed(t(snps),snps)+mrMLM::multiplication_speed(t(1-snps),(1-snps)))/nrow(snps)
     diag(K) <- 1
     return(K)
   }
@@ -1012,34 +1013,10 @@ REML.LRT.c2.new<-data.frame(REML.LRT.c2)
 rm(C2,mydata)
 gc()
 
-#parms<-data.frame(chr.locus=xnames,REML.LRT.c2.new,MAF,pve.allr2)
 parms<-data.frame(chr.locus=xnames,REML.LRT.c2.new)
 names(parms)<-NULL
 parms<-as.matrix(parms)
 
-ress<-parms[,1:3]
-ress1<-ress[ress[,3]!=1,]
-resp<-as.matrix(ress1[,3])
-pmin<-min(resp[resp!=0])
-locsub<-which(resp==0)
-if(length(locsub)!=0){
-  subvalue<-10^(1.1*log10(pmin))
-  ress1[locsub,3]<-subvalue
-  ress1<-ress1
-}else{
-  ress1<-ress1
-}
-
-rowsnp <- dim(ress1)[1]
-snpname <- numeric()
-snpname<-as.matrix(paste("rs",c(1:rowsnp),sep = ""))
-snpname<-snpname
-
-pe<-as.numeric(parms[,6])
-pee<-sum(pe)
-newp<-0.05/pee
-mannewp<-newp
-
 
 parmeter<-parms[,1:4]
 parmeter[,3]<--log10(parmeter[,3])
@@ -1050,7 +1027,7 @@ parmeter[which( abs(parmeter)<1e-4)]<-as.numeric(sprintf("%.4e", parmeter[which(
 if(inputform==1){
   parmsShow<-cbind(genRaw[-1,1],parmeter,genRaw[-1,4])
   parmsShow<-parmsShow[,c(1,2,3,5,4,6)]
-colnames(parmsShow)<-c("Marker","Chromosome","Marker position (bp)","SNP effect","'-log10(P)'","Genotype for code 1")
+  colnames(parmsShow)<-c("Marker","Chromosome","Marker position (bp)","SNP effect (FASTmrEMMA)","'-log10(P) (FASTmrEMMA)'","Genotype for code 1")
   
 }
 if(inputform==2){
@@ -1058,7 +1035,7 @@ if(inputform==2){
   meadd<-matrix(" ",nrow(parms),1)
   parmsShow<-cbind(genRaw[-1,1],parmeter,outATCG)
   parmsShow<-parmsShow[,c(1,2,3,5,4,6)]
-  colnames(parmsShow)<-c("Marker","Chromosome","Marker position (bp)","SNP effect","'-log10(P)'","Genotype for code 1")
+  colnames(parmsShow)<-c("Marker","Chromosome","Marker position (bp)","SNP effect (FASTmrEMMA)","'-log10(P) (FASTmrEMMA)'","Genotype for code 1")
   
 }
 if(inputform==3){
@@ -1068,34 +1045,10 @@ if(inputform==3){
   
   parmsShow<-cbind(genRaw[-1,1],parmeter,outATCG)
   parmsShow<-parmsShow[,c(1,2,3,5,4,6)]
-  colnames(parmsShow)<-c("Marker","Chromosome","Marker position (bp)","SNP effect","'-log10(P)'","Genotype for code 1")
+  colnames(parmsShow)<-c("Marker","Chromosome","Marker position (bp)","SNP effect (FASTmrEMMA)","'-log10(P) (FASTmrEMMA)'","Genotype for code 1")
 }
 
 
-bpnumber <- numeric()
-chrnum <- unique(ress1[,1])
-for(i in 1:length(chrnum))
-{
-  bpnumber <- rbind(bpnumber,as.matrix(c(1:length(which(ress1[,1]==chrnum[i])))))
-}
-parms <- data.frame(ress1,snpname,bpnumber)
-colnames(parms)<-c("Chromosome","Position","P-value","SNPname","BPnumber")
-parms<-parms[,-2]
-
-mannewp <- as.matrix(mannewp)
-rowbl<-matrix("",(nrow(parms)-1),1)
-mannepr<-rbind(mannewp,rowbl)
-colnames(mannepr)<-"Manhattan p-value"
-
-parms<-cbind(as.matrix(parms),mannepr)
-parms<-as.data.frame(parms,stringsAsFactors=FALSE)
-parms[,c(1,2,4)]<-sapply(parms[,c(1,2,4)],as.numeric)
-ress1<-as.data.frame(ress1[,-(1:2)])
-
-colnames(ress1)<-"P-value"
-
-
-
 Xemma<-data.frame(chr.locus=xnames,REML.LRT.c2.new)
 vid<-which(as.numeric(Xemma[,3])<=svpal)
 
@@ -1220,7 +1173,7 @@ if(length(vid)!=0){
     
   }  
 }  
-output<-list(result1=parmsShow,result2=wan,Manhattan=parms,QQ=ress1)
+output<-list(result1=parmsShow,result2=wan)
 return(output)
 }
 }
